/**
 * Set error action.
 * @remarks
 * Used to set a top level error on the machine. This may equal to {@link @genesislcap/foundation-utils#ErrorMap} `lastError` in the `errors` property.
 * @privateRemarks
 * Contains done event handling to deal with 200 Nacks.
 * @public
 */
export declare const setError: {
    (_: import("xstate").ActionArgs<import("xstate").MachineContext, import("xstate").EventObject, import("xstate").ParameterizedObject>): void;
    type: string;
    assignment: import("xstate").Assigner<import("xstate").MachineContext, import("xstate").EventObject> | import("xstate").PropertyAssigner<import("xstate").MachineContext, import("xstate").EventObject>;
    resolve: (actorContext: import("xstate").AnyActorContext, state: import("xstate").AnyState, actionArgs: import("xstate").ActionArgs<any, any, import("xstate").ParameterizedObject>, { assignment }: {
        assignment: import("xstate").Assigner<any, any> | import("xstate").PropertyAssigner<any, any>;
    }) => import("xstate").AnyState[];
};
/**
 * Set error by key action.
 * @remarks
 * Used to set an error in the {@link @genesislcap/foundation-utils#ErrorMap} by key.
 * @privateRemarks
 * Contains done event handling to deal with 200 Nacks. If done output is an error use it, or fallback to `context.error`
 * and set that under the provided key.
 * @param key - The error key.
 * @public
 */
export declare const setErrorByKey: (key: string) => {
    (_: import("xstate").ActionArgs<import("xstate").MachineContext, import("xstate").EventObject, import("xstate").ParameterizedObject>): void;
    type: string;
    assignment: import("xstate").Assigner<import("xstate").MachineContext, import("xstate").EventObject> | import("xstate").PropertyAssigner<import("xstate").MachineContext, import("xstate").EventObject>;
    resolve: (actorContext: import("xstate").AnyActorContext, state: import("xstate").AnyState, actionArgs: import("xstate").ActionArgs<any, any, import("xstate").ParameterizedObject>, { assignment }: {
        assignment: import("xstate").Assigner<any, any> | import("xstate").PropertyAssigner<any, any>;
    }) => import("xstate").AnyState[];
};
/**
 * Escalate context error action.
 * @remarks
 * Guard this call with a parent check to avoid warnings when there's no parent.
 * @public
 */
export declare const escalateError: {
    (_: import("xstate").ActionArgs<import("xstate").MachineContext, import("xstate").EventObject, import("xstate").ParameterizedObject>): void;
    type: string;
    to: string | import("xstate").AnyActorRef | ((args: import("xstate").UnifiedArg<import("xstate").MachineContext, import("xstate").EventObject>) => string | import("xstate").AnyActorRef);
    event: any;
    id: string;
    delay: string | number | import("xstate").DelayExpr<import("xstate").MachineContext, import("xstate").EventObject>;
    resolve: (actorContext: import("xstate").AnyActorContext, state: import("xstate").AnyState, args: import("xstate").ActionArgs<any, any, import("xstate").ParameterizedObject>, { to, event: eventOrExpr, id, delay }: {
        to: string | import("xstate").AnyActorRef | ((args: import("xstate").UnifiedArg<import("xstate").MachineContext, import("xstate").EventObject>) => string | import("xstate").AnyActorRef);
        event: import("xstate").EventObject | import("xstate").SendExpr<import("xstate").MachineContext, import("xstate").EventObject, import("xstate").EventObject>;
        id: string;
        delay: string | number | import("xstate").DelayExpr<import("xstate").MachineContext, import("xstate").EventObject>;
    }) => (import("xstate").AnyState | {
        to: import("xstate").AnyActorRef;
        event: import("xstate").EventObject;
        id: string;
        delay: number;
    })[];
    execute: (actorContext: import("xstate").AnyActorContext, params: {
        to: import("xstate").AnyActorRef;
        event: import("xstate").EventObject;
        id: string;
        delay: number;
    }) => void;
};
//# sourceMappingURL=actions.d.ts.map