/**
 * NetworkError.
 * @remarks
 * Failed to reach server.
 * @public
 */
export declare class NetworkError extends Error {
    url: string;
    constructor(url: string, message?: string);
}
/**
 * APIError.
 * @remarks
 * Bad server `Response`.
 * @public
 */
export declare class APIError extends Error {
    status: number;
    data?: unknown;
    constructor(status: number, data?: unknown, message?: string);
    /**
     * @public
     */
    isUnauthorized(): boolean;
}
/**
 * @param error - An error.
 * @public
 */
export declare const isAPIError: (error: unknown) => error is APIError;
/**
 * @param error - An error.
 * @public
 */
export declare const isNetworkError: (error: unknown) => error is NetworkError;
/**
 * @param error - An error.
 * @public
 */
export declare const isNotFoundError: (error: {
    status?: number;
}) => error is APIError;
/**
 * @param error - An error.
 * @public
 */
export declare const isUnauthorizedError: (error: {
    status?: number;
}) => error is APIError;
//# sourceMappingURL=errors.d.ts.map