import type { IMergedPolicy } from 'cockatiel';
import type { InterpreterOptions } from 'xstate';
import { AbstractMachine, Machine } from '../../core';
import type { FetchMachineContext, FetchMachineEvent, ResponseDataExtractor, ResponseOkChecker } from './types';
/**
 * FetchConfig interface.
 * @public
 */
export interface FetchConfig {
    /**
     * Defaults to {@link typescript#fetch}.
     * @privateRemarks
     * This config property allows us to mock {@link typescript#Response | responses} during testing.
     */
    fetcher: typeof fetch;
    /**
     * Defaults to {@link defaultFetchPolicy}
     */
    fetchPolicy?: IMergedPolicy<any, any, any>;
    /**
     * Defaults to {@link defaultResponseOkChecker}
     */
    responseOkChecker?: ResponseOkChecker;
    /**
     * Defaults to {@link defaultResponseDataExtractor}
     */
    responseDataExtractor?: ResponseDataExtractor;
}
/**
 * FetchConfig DI key.
 * @internal
 */
export declare const FetchConfig: import("@microsoft/fast-foundation").InterfaceSymbol<FetchConfig>;
/**
 * FetchMachine interface.
 * @public
 */
export interface FetchMachine extends Machine<FetchMachineContext, FetchMachineEvent> {
}
/**
 * Default FetchMachine.
 * @public
 */
export declare class DefaultFetchMachine extends AbstractMachine<FetchMachineContext, FetchMachineEvent> implements FetchMachine {
    private config;
    constructor(config?: FetchConfig);
    /** {@inheritDoc Machine.start} */
    start(options?: InterpreterOptions<typeof this.machine>): void;
    /** {@inheritDoc Machine.getFromContainer} */
    getFromContainer(): this;
}
/**
 * FetchMachine DI key.
 * @internal
 */
export declare const FetchMachine: import("@microsoft/fast-foundation").InterfaceSymbol<FetchMachine>;
//# sourceMappingURL=machine.d.ts.map