import type { IBackoffFactory, IRetryBackoffContext } from 'cockatiel';
import { StatusCodes } from 'http-status-codes';
/**
 * Default retry stats codes.
 * @public
 */
export declare const defaultRetryStatsCodes: StatusCodes[];
/**
 * A fetch policy factory.
 * @remarks
 * Will retry network errors and responses with certain status codes up to the specified max attempts.
 * @param maxAttempts - Max attempts. Defaults to `2`.
 * @param retryCodes - Status code array to retry. Defaults to {@link defaultRetryStatsCodes}.
 * @param backoff - Backoff algo. Defaults to {@link cockatiel#ExponentialBackoff}.
 * @param timeoutDuration - Timeout duration. Defaults to 3 seconds.
 * @param logEvents - Log events to the console. Defaults to `true`.
 * @public
 */
export declare const createFetchPolicy: (maxAttempts?: number, retryCodes?: StatusCodes[] | number[], backoff?: IBackoffFactory<IRetryBackoffContext<unknown>>, timeoutDuration?: number, logEvents?: boolean) => import("cockatiel").IMergedPolicy<import("cockatiel").IRetryContext & import("cockatiel").ICancellationContext, never, [import("cockatiel").RetryPolicy, import("cockatiel").TimeoutPolicy]>;
/**
 * The default fetch policy.
 * @public
 */
export declare const defaultFetchPolicy: import("cockatiel").IMergedPolicy<import("cockatiel").IRetryContext & import("cockatiel").ICancellationContext, never, [import("cockatiel").RetryPolicy, import("cockatiel").TimeoutPolicy]>;
//# sourceMappingURL=policies.d.ts.map