/**
 * GenesisServerError.
 * @remarks
 * Represents an error received from a Genesis Server.
 * @public
 */
export class GenesisServerError extends Error {
    constructor(sent, received, message = 'Genesis Server Error Occurred') {
        super(message);
        this.sent = sent;
        this.received = received;
        this.name = 'GenesisServerError';
        Object.setPrototypeOf(this, GenesisServerError.prototype);
    }
    /**
     * Capture known edge cases.
     * @privateRemarks
     * This is ugly, lets figure out if this is still an issue and remove if not.
     */
    isIgnorableError() {
        var _a, _b, _c, _d;
        if ((_d = (_c = (_b = (_a = this.received) === null || _a === void 0 ? void 0 : _a.DETAILS) === null || _b === void 0 ? void 0 : _b.ERROR) === null || _c === void 0 ? void 0 : _c.toLowerCase()) === null || _d === void 0 ? void 0 : _d.includes('request needs the user to be logged')) {
            return true;
        }
        return false;
    }
    getMessageError() {
        var _a, _b;
        return Array.isArray((_a = this.received) === null || _a === void 0 ? void 0 : _a.ERROR)
            ? (_b = this.received) === null || _b === void 0 ? void 0 : _b.ERROR.map((error) => this.errorDetailFormatter(error)).join('\n')
            : '';
    }
    getDetailsError() {
        var _a, _b, _c, _d;
        return Array.isArray((_b = (_a = this.received) === null || _a === void 0 ? void 0 : _a.DETAILS) === null || _b === void 0 ? void 0 : _b.ERROR)
            ? (_d = (_c = this.received) === null || _c === void 0 ? void 0 : _c.DETAILS) === null || _d === void 0 ? void 0 : _d.ERROR.map((error) => this.errorDetailFormatter(error)).join('\n')
            : '';
    }
    hasErrorCode(code) {
        var _a, _b;
        return Array.isArray((_a = this.received) === null || _a === void 0 ? void 0 : _a.ERROR)
            ? (_b = this.received) === null || _b === void 0 ? void 0 : _b.ERROR.some((error) => error.CODE === code)
            : false;
    }
    errorDetailFormatter(error) {
        return `\n ${error.CODE}: \n ${error.TEXT}`;
    }
}
/**
 * @param error - An error.
 * @public
 */
export const isGenesisServerError = (error) => error instanceof GenesisServerError;
/**
 * MappingError.
 * @public
 */
export class MappingError extends Error {
    constructor(dto, message = 'Mapping Error Occurred') {
        super(message);
        this.dto = dto;
        this.name = 'MappingError';
        Object.setPrototypeOf(this, MappingError.prototype);
    }
}
/**
 * @param error - An error.
 * @public
 */
export const isMappingError = (error) => error instanceof MappingError;
