import { TaskCancelledError } from 'cockatiel';
/**
 * assertEvent.
 * @privateRemarks
 * Note `asserts` need to be functions to work.
 * @param event - An event.
 * @param type - An event type.
 * @public
 */
export function assertEvent(event, type) {
    if (event.type !== type) {
        throw new Error(`${type} event type expected, received ${event.type}.`);
    }
}
/**
 * isDoneInvokeEvent.
 * @param event - An event.
 * @public
 */
export const isDoneInvokeEvent = (event) => /^done.invoke/.test(event.type);
/**
 * isErrorEvent.
 * @param event - An event.
 * @public
 */
export const isErrorEvent = (event) => /^error.platform/.test(event.type);
/**
 * isErrorCustomEvent.
 * @remarks
 * What `escalate` from a child is typed as.
 * @param event - An event.
 * @public
 */
export const isErrorCustomEvent = (event) => /^xstate.error/.test(event.type);
/**
 * isActorErrorEvent.
 * @param actorId - An actor id.
 * @param event - An event.
 * @public
 */
export const isActorErrorEvent = (actorId, event) => { var _a, _b; return ((_a = event.type) === null || _a === void 0 ? void 0 : _a.includes('error')) && ((_b = event.type) === null || _b === void 0 ? void 0 : _b.includes(actorId)); };
/**
 * isEventWithParams.
 * @param event - An event.
 * @public
 */
export const isEventWithParams = (event) => event.params !== undefined;
/**
 * isErrorType.
 * @param type - An event type.
 * @public
 */
export const isErrorType = (type) => (event) => {
    if (isErrorEvent(event)) {
        return event.data instanceof type;
    }
    return false;
};
/**
 * isTypeError.
 * @public
 */
export const isTypeError = ({ event }) => isErrorType(TypeError)(event);
/**
 * isSyntaxError.
 * @public
 */
export const isSyntaxError = ({ event }) => isErrorType(SyntaxError)(event);
/**
 * isAbortError.
 * @public
 */
export const isAbortError = ({ event }) => {
    if (isErrorEvent(event)) {
        return ((event.data instanceof DOMException && event.data.code == DOMException.ABORT_ERR) ||
            event.data instanceof TaskCancelledError);
    }
    return false;
};
