import { escalateError, setErrorByKey } from './actions';
/**
 * Creates an error state node.
 *
 * @param key - An error state key.
 * @param metaContent - An optional meta content value.
 * @param final - An optional flag which adds final with output functionality.
 * @public
 */
export const createErrorStateNode = (key, metaContent, final = true) => {
    /**
     * Raised question on reuse and dynamic parent detection, regarding error escalation.
     * https://github.com/statelyai/xstate/discussions/4268
     */
    let hasParentMachine = false;
    let sentToParentMachine = false;
    return {
        tags: ['error', key],
        meta: {
            content: metaContent ? metaContent : `${key} error.`,
        },
        entry: [
            setErrorByKey(`${key}-error`),
            (args) => (hasParentMachine = args.self._parent !== undefined),
        ],
        always: [
            {
                guard: () => hasParentMachine && !sentToParentMachine,
                actions: [escalateError, () => (sentToParentMachine = true)],
            },
        ],
        /**
         * Provide final output to parent machines.
         */
        type: final ? 'final' : 'atomic',
        output: ({ context }) => context.error,
    };
};
