import { StatusCodes } from 'http-status-codes';
/**
 * NetworkError.
 * @remarks
 * Failed to reach server.
 * @public
 */
export class NetworkError extends Error {
    constructor(url, message = 'Network Error Occurred') {
        super(message);
        this.url = url;
        this.name = 'NetworkError';
        Object.setPrototypeOf(this, NetworkError.prototype);
    }
}
/**
 * APIError.
 * @remarks
 * Bad server `Response`.
 * @public
 */
export class APIError extends Error {
    constructor(status, data, message = 'API Error Occurred') {
        super(message);
        this.status = status;
        this.data = data;
        this.name = 'APIError';
        Object.setPrototypeOf(this, APIError.prototype);
    }
    /**
     * @public
     */
    isUnauthorized() {
        return this.status === StatusCodes.UNAUTHORIZED;
    }
}
/**
 * @param error - An error.
 * @public
 */
export const isAPIError = (error) => error instanceof APIError;
/**
 * @param error - An error.
 * @public
 */
export const isNetworkError = (error) => error instanceof NetworkError ||
    (error instanceof TypeError && error.message === 'Failed to fetch');
/**
 * @param error - An error.
 * @public
 */
export const isNotFoundError = (error) => isAPIError(error) && error.status === StatusCodes.NOT_FOUND;
/**
 * @param error - An error.
 * @public
 */
export const isUnauthorizedError = (error) => isAPIError(error) && error.isUnauthorized();
