import { __awaiter } from "tslib";
import { JSONReviver } from '@genesislcap/foundation-utils';
import { defaultFetchPolicy } from './policies';
/**
 * {@inheritDoc ResponseOkChecker}
 * @public
 */
export const defaultResponseOkChecker = (response) => response.ok;
/**
 * {@inheritDoc ResponseDataExtractor}
 * @public
 */
export const defaultResponseDataExtractor = (response) => __awaiter(void 0, void 0, void 0, function* () {
    const text = yield response.text();
    const contentType = response.headers.get('content-type');
    const expectingJson = contentType === null || contentType === void 0 ? void 0 : contentType.includes('application/json');
    return expectingJson ? JSON.parse(text, JSONReviver) : text;
});
/**
 * Creates an extractor that applies a deserializer to the extracted response data.
 * @param deserializer - The deserializer to apply.
 * @param extractor - An optional data extractor. Defaults to {@link defaultResponseDataExtractor}.
 * @public
 */
export const createResponseDataExtractorWithDeserializer = (deserializer, extractor = defaultResponseDataExtractor) => (response) => __awaiter(void 0, void 0, void 0, function* () {
    const json = yield extractor(response);
    return deserializer(json);
});
/**
 * The default fetch config.
 * @public
 */
export const defaultFetchConfig = {
    fetcher: fetch,
    fetchPolicy: defaultFetchPolicy,
    responseOkChecker: defaultResponseOkChecker,
    responseDataExtractor: defaultResponseDataExtractor,
};
/**
 * Default FetchMachineContext.
 * @public
 */
export const defaultFetchMachineContext = {
    params: undefined,
    controller: undefined,
    response: undefined,
    data: undefined,
};
