<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [@genesislcap/foundation-state-machine](./foundation-state-machine.md) &gt; [Machine](./foundation-state-machine.machine.md)

## Machine interface

Machine interface.

**Signature:**

```typescript
export interface Machine<TContext extends MachineContext, TEvent extends EventObject = AnyEventObject, TAction extends ParameterizedObject = ParameterizedObject, TActor extends ProvidedActor = ProvidedActor, TInput = any, TResolvedTypesMeta = ResolveTypegenMeta<TypegenDisabled, NoInfer<TEvent>, TAction, TActor>> 
```

## Remarks

The interface of our xstate based machines or logic workflows. These contain bindable properties for convenience. Should be extended.

## Example 1

Creating a machine in the DI.

```ts
export interface MyMachine extends Machine<MyMachineContext, MyMachineEvent> {
  readonly service: MyService;
  ...
}
export class DefaultMyMachine
  extends AbstractMachine<MyMachineContext, MyMachineEvent>
  implements MyMachine
{
  constructor(@MyService readonly service: MyService) {
    super();
    this.machine = createMachine<MyMachineContext, MyMachineEvent>(...);
    this.start(); // < Call now or later to ready the machine.
  }
  start(
    options: InterpreterOptions<typeof this.machine> = {
      input: myDefaultContext,
    },
  ) {
    super.start(options);
  }
}
// Whether the machine should be `transient` or a `singleton` probably depends on the use case and if it contains a `final` state.
export const MyMachine = DI.createInterface<MyMachine>((x) => x.transient(DefaultMyMachine));
```
Machines are bindable from templates and other logic.

## Example 2

Surface errors in a template.

```ts
${when(
  (x) => !!x.myMachine.errors.size,
  html<MyComponent>`
    <span>${(x) => x.myMachine.errors.messages}</span>
  `,
)}
```

## Example 3

Use context data in a class.

```ts
this.myMachine.binding((x) => x.context.data, (value) => {
  // use data
});
```

## Properties

|  Property | Modifiers | Type | Description |
|  --- | --- | --- | --- |
|  [actor?](./foundation-state-machine.machine.actor.md) | <code>readonly</code> | InterpreterFrom&lt;StateMachine&lt;TContext, TEvent, TAction, TActor, TInput, TResolvedTypesMeta&gt;&gt; | _(Optional)_ Optional actor |
|  [complete](./foundation-state-machine.machine.complete.md) | <code>readonly</code> | boolean | Indicates if the machine has completed the happy path. |
|  [context](./foundation-state-machine.machine.context.md) | <code>readonly</code> | Partial&lt;TContext&gt; | The current <code>context</code> of the machine. The data points in context may be considered transient in nature. |
|  [error](./foundation-state-machine.machine.error.md) | <code>readonly</code> | any | A general machine error. Likely equal to <code>errors.lastError</code>. |
|  [errors](./foundation-state-machine.machine.errors.md) | <code>readonly</code> | ErrorMap&lt;ErrorDetailMap&gt; | An  of errors that may have occurred during the machine's workflows. |
|  [machine](./foundation-state-machine.machine.machine.md) | <code>readonly</code> | StateMachine&lt;TContext, TEvent, TAction, TActor, TInput, TResolvedTypesMeta&gt; | Mandatory machine property. |
|  [meta](./foundation-state-machine.machine.meta.md) | <code>readonly</code> | Record&lt;string, any&gt; | The <code>meta</code> from the current <code>state</code>. |
|  [output](./foundation-state-machine.machine.output.md) | <code>readonly</code> | any | Holds successful machine output if any. |
|  [snapshot](./foundation-state-machine.machine.snapshot.md) | <code>readonly</code> | State&lt;TContext, TEvent, TActor, TResolvedTypesMeta&gt; | The last <code>snapshot</code> from the actor. |
|  [startingContext](./foundation-state-machine.machine.startingcontext.md) | <code>readonly</code> | Partial&lt;TContext&gt; | The <code>context</code> of the machine when started. |
|  [startingState](./foundation-state-machine.machine.startingstate.md) | <code>readonly</code> | StateValue | The <code>state</code> of the machine when started. Allows consumers to start a machine from a persisted state. |
|  [state](./foundation-state-machine.machine.state.md) | <code>readonly</code> | StateValue | The current <code>state</code> of the machine itself. This is not to be confused with state in the data or store sense. |

## Methods

|  Method | Description |
|  --- | --- |
|  [binding(token, subscriberChangeCallback, isVolatileBinding, context)](./foundation-state-machine.machine.binding.md) | An api to allow the observation of values and arbitrary bindings outside the template engine. |
|  [getFromContainer()](./foundation-state-machine.machine.getfromcontainer.md) | Gets the machine from the container. |
|  [getMetaValuesByKey(key)](./foundation-state-machine.machine.getmetavaluesbykey.md) | Get <code>meta</code> values by key. |
|  [hasTag(tag)](./foundation-state-machine.machine.hastag.md) | Check <code>tags</code> contain provided tag. |
|  [matches(value)](./foundation-state-machine.machine.matches.md) | Check <code>state</code> matches provided value. |
|  [onSendEvent(event)](./foundation-state-machine.machine.onsendevent.md) | A custom event handler to send events to the machine. |
|  [provide(implementations)](./foundation-state-machine.machine.provide.md) | Recreate the internal machine with the provided implementations. |
|  [send(event)](./foundation-state-machine.machine.send.md) | An api to send events to the machine. |
|  [start(options)](./foundation-state-machine.machine.start.md) | Start the machine. |
|  [stop()](./foundation-state-machine.machine.stop.md) | Stop the machine. |

